@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import IO, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -268,6 +268,7 @@ IntegrationTypeDef = TypedDict(
         "PayloadFormatVersion": str,
         "RequestParameters": Dict[str, str],
         "RequestTemplates": Dict[str, str],
+        "ResponseParameters": Dict[str, Dict[str, str]],
         "TemplateSelectionExpression": str,
         "TimeoutInMillis": int,
         "TlsConfig": "TlsConfigTypeDef",
@@ -510,6 +511,7 @@ CreateIntegrationResultTypeDef = TypedDict(
         "PayloadFormatVersion": str,
         "RequestParameters": Dict[str, str],
         "RequestTemplates": Dict[str, str],
+        "ResponseParameters": Dict[str, Dict[str, str]],
         "TemplateSelectionExpression": str,
         "TimeoutInMillis": int,
         "TlsConfig": "TlsConfigTypeDef",
@@ -592,7 +594,9 @@ CreateVpcLinkResponseTypeDef = TypedDict(
     total=False,
 )
 
-ExportApiResponseTypeDef = TypedDict("ExportApiResponseTypeDef", {"body": bytes}, total=False)
+ExportApiResponseTypeDef = TypedDict(
+    "ExportApiResponseTypeDef", {"body": Union[bytes, IO[bytes]]}, total=False
+)
 
 GetApiMappingResponseTypeDef = TypedDict(
     "GetApiMappingResponseTypeDef",
@@ -732,6 +736,7 @@ GetIntegrationResultTypeDef = TypedDict(
         "PayloadFormatVersion": str,
         "RequestParameters": Dict[str, str],
         "RequestTemplates": Dict[str, str],
+        "ResponseParameters": Dict[str, Dict[str, str]],
         "TemplateSelectionExpression": str,
         "TimeoutInMillis": int,
         "TlsConfig": "TlsConfigTypeDef",
@@ -1010,6 +1015,7 @@ UpdateIntegrationResultTypeDef = TypedDict(
         "PayloadFormatVersion": str,
         "RequestParameters": Dict[str, str],
         "RequestTemplates": Dict[str, str],
+        "ResponseParameters": Dict[str, Dict[str, str]],
         "TemplateSelectionExpression": str,
         "TimeoutInMillis": int,
         "TlsConfig": "TlsConfigTypeDef",
